:mod:`qt_binder.bound_editor`
=============================

.. currentmodule:: qt_binder.bound_editor

.. autoclass:: Bound
    :members:
    :show-inheritance:

----

.. autoclass:: TraitsUI
    :members:
    :show-inheritance:
